#!/usr/bin/env python

# Copyright and license: Please refer to LICENSE.TXT

import sys
import os
import os.path
import string
import re
import time

_selfpath=(os.path.dirname(os.path.realpath(__file__)).split('/'))[:-1]
_selfpath.append('pylibs')
_libspath='/'.join(_selfpath)
sys.path.append(_libspath)

from castiron import *

sys.path.append(CORE_PATH_BASE+'/pylibs')

from s2p import *
from s2p_logger import *

#############################################################################################################
# Check config parameters

CORE_CONF_SYSTEM		= xml_to_array(CORE_PATH_BASE+'/config/system.xml')
CASTIRON_CONF_BACKUP	= xml_to_array(CASTIRON_PATH_BASE+'/config/backup.xml')

if CASTIRON_CONF_BACKUP['config']['enabled'] != 'true': sys.exit(0)

#############################################################################################################
# Check backup frequency

frequency=CASTIRON_CONF_BACKUP['config']['frequency']

do_backup=False

if len(sys.argv)<2 or sys.argv[1] != 'cron':
	s2p_log("castiron", "info", "Manually creating config backup")
	do_backup=True

if len(sys.argv)>1 and sys.argv[1] == 'cron' and frequency == 'manual':
	sys.exit(0)

ltime=time.localtime()

hours_m		= re.match(r'^(?P<n>\d+)h$', frequency)
days_m		= re.match(r'^(?P<n>\d+)d$', frequency)
weeks_m		= re.match(r'^(?P<n>\d+)w$', frequency)
months_m	= re.match(r'^(?P<n>\d+)m$', frequency)

if hours_m and not (ltime[3] % int(hours_m.group('n'))):
	do_backup=True

elif days_m and not (ltime[7] % int(days_m.group('n'))) and not int(ltime[3]):
	do_backup=True

elif weeks_m and not (ltime[6] % int(weeks_m.group('n'))) and not int(ltime[3]):
	do_backup=True

elif months_m and not (ltime[1] % int(months_m.group('n'))) and not int(ltime[3]) and int(ltime[2]) == 1:
	do_backup=True

if not do_backup: sys.exit(0)

#############################################################################################################
# Do backup

backup_file=re.sub(r'[\n\r]+', '', systempt(CORE_PATH_BASE+'/bin/backup.sh'))

#############################################################################################################
# Email variables

# Variables
fp=open('/etc/hostname', 'r')
hostname=re.sub(r'[\n\r]+', '', fp.read())
fp.close()

sys_vars={
	'sysname':			CORE_CONF_SYSTEM['hq']['sysname'],
	'server':			hostname,
	'hostname':			hostname,
	'date-time':		time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
}

#############################################################################################################
# Send backup

subject	= set_vars(CASTIRON_CONF_BACKUP['config']['message-template-subject'], sys_vars)
body	= set_vars(CASTIRON_CONF_BACKUP['config']['message-template-body'], sys_vars)

res=ci_media_send({
	'media': 	CASTIRON_CONF_BACKUP['config']['media'],
	'subject':	subject,
	'body':		body,
	'files':	[backup_file]
})

os.unlink(backup_file)

if res:
	s2p_log("castiron", "info", "Configuration backup sent")
	sys.exit(0)
	
else:
	s2p_log("castiron", "error", "Could not send configuration backup")
	sys.exit(-1)



